===============
Technical Notes
===============

This chapter collects a number of technical advises for using scikit-gstat.
These examples either give details on the implementation or 
guide a correct package usage. This are technical notes, no tutorials. 
The application of the shown examples might not make sense in every situation

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    fitting
    direction
    estimate_kriging
